==> xn-ultralytics-1.0.0.tar.gz: xn-ultralytics-1.0.0/setup.py <==
# Ultralytics YOLO 🚀, AGPL-3.0 license

import re
from pathlib import Path

import pkg_resources as pkg
from setuptools import find_packages, setup

# Settings
FILE = Path(__file__).resolve()
PARENT = FILE.parent  # root directory
README = (PARENT / "README.md").read_text(encoding="utf-8")
REQUIREMENTS = [
    f"{x.name}{x.specifier}"
    for x in pkg.parse_requirements((PARENT / "requirements.txt").read_text())
]


def get_version():
    file = PARENT / "ultralytics/__init__.py"
    return re.search(
        r'^__version__ = [\'"]([^\'"]*)[\'"]', file.read_text(encoding="utf-8"), re.M
    )[1]


setup(
    name="xn-ultralytics",  # name of pypi package
    version=get_version(),  # version of pypi package
    python_requires=">=3.7",
    license="AGPL-3.0",
    description=(
        "This is a public fork of Ultralytics YOLOv8 for SOTA object detection, multi-object tracking, instance segmentation, "
        "pose estimation and image classification. Free for anyone to use, for non-commercial purposes."
    ),
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/ultralytics/ultralytics",
    project_urls={
        "Bug Reports": "https://github.com/ultralytics/ultralytics/issues",
        "Funding": "https://ultralytics.com",
        "Source": "https://github.com/ultralytics/ultralytics",
    },
    author="Sebastian Beyer",
    author_email="sebastian.beyer@live.com",
    packages=find_packages(),  # required
    include_package_data=True,
    install_requires=REQUIREMENTS,
    extras_require={
        "dev": [
            "check-manifest",
            "pytest",
            "pytest-cov",
            "coverage",
            "mkdocs-material",
            "mkdocstrings[python]",
            "mkdocs-redirects",  # for 301 redirects
            "mkdocs-ultralytics-plugin",  # for meta descriptions and images, dates and authors
        ],
        "export": [
            "coremltools>=6.0",
            "openvino-dev>=2022.3",
            "tensorflowjs",
        ],  # automatically installs tensorflow
    },
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Intended Audience :: Education",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Topic :: Software Development",
        "Topic :: Scientific/Engineering",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
        "Topic :: Scientific/Engineering :: Image Recognition",
        "Operating System :: POSIX :: Linux",
        "Operating System :: MacOS",
        "Operating System :: Microsoft :: Windows",
    ],
    keywords="machine-learning, deep-learning, vision, ML, DL, AI, YOLO, YOLOv3, YOLOv5, YOLOv8, HUB, Ultralytics",
    entry_points={
        "console_scripts": [
            "yolo = ultralytics.yolo.cfg:entrypoint",
            "ultralytics = ultralytics.yolo.cfg:entrypoint",
        ]
    },
)

==> xn-ultralytics-8.0.119.tar.gz: xn-ultralytics-8.0.119/setup.py <==
# Ultralytics YOLO 🚀, AGPL-3.0 license

import re
from pathlib import Path

import pkg_resources as pkg
from setuptools import find_packages, setup

# Settings
FILE = Path(__file__).resolve()
PARENT = FILE.parent  # root directory
README = (PARENT / "README.md").read_text(encoding="utf-8")
REQUIREMENTS = [
    f"{x.name}{x.specifier}"
    for x in pkg.parse_requirements((PARENT / "requirements.txt").read_text())
]


def get_version():
    file = PARENT / "ultralytics/__init__.py"
    return re.search(
        r'^__version__ = [\'"]([^\'"]*)[\'"]', file.read_text(encoding="utf-8"), re.M
    )[1]


setup(
    name="xn-ultralytics",  # name of pypi package
    version=get_version(),  # version of pypi package
    python_requires=">=3.7",
    license="AGPL-3.0",
    description=(
        "This is a public fork of Ultralytics YOLOv8 for SOTA object detection, multi-object tracking, instance segmentation, "
        "pose estimation and image classification. Free for anyone to use, for non-commercial purposes."
    ),
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://git.ex-nihilo.ai/3rdparty/xn-ultralytics",
    project_urls={
        "Bug Reports": "https://git.ex-nihilo.ai/3rdparty/xn-ultralytics/issues",
        "Funding": "https://ultralytics.com",
        "Source": "https://git.ex-nihilo.ai/3rdparty/xn-ultralytics",
    },
    author="Sebastian Beyer",
    author_email="sebastian.beyer@live.com",
    packages=find_packages(),  # required
    include_package_data=True,
    install_requires=REQUIREMENTS,
    extras_require={
        "dev": [
            "check-manifest",
            "pytest",
            "pytest-cov",
            "coverage",
            "mkdocs-material",
            "mkdocstrings[python]",
            "mkdocs-redirects",  # for 301 redirects
            "mkdocs-ultralytics-plugin",  # for meta descriptions and images, dates and authors
        ],
        "export": [
            "coremltools>=6.0",
            "openvino-dev>=2022.3",
            "tensorflowjs",
        ],  # automatically installs tensorflow
    },
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Intended Audience :: Education",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Topic :: Software Development",
        "Topic :: Scientific/Engineering",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
        "Topic :: Scientific/Engineering :: Image Recognition",
        "Operating System :: POSIX :: Linux",
        "Operating System :: MacOS",
        "Operating System :: Microsoft :: Windows",
    ],
    keywords="machine-learning, deep-learning, vision, ML, DL, AI, YOLO, YOLOv3, YOLOv5, YOLOv8, HUB, Ultralytics",
    entry_points={
        "console_scripts": [
            "yolo = ultralytics.yolo.cfg:entrypoint",
            "ultralytics = ultralytics.yolo.cfg:entrypoint",
        ]
    },
)
